@@ -4,6 +4,7 @@ from PIL import ImageFont
 
 from viso_sdk.constants import FONTS_DIR
 from viso_sdk.logging import get_logger
+from viso_sdk.visualize.palette import get_rgba_color
 
 pil_version = PIL.__version__
 logger = get_logger("vis-font")
@@ -11,16 +12,16 @@ logger = get_logger("vis-font")
 
 DEFAULT_FONT_SIZE = 15
 DEFAULT_FONT_NAME = "Roboto-Medium"
-DEFAULT_TXT_COLOR = (255, 255, 255, 1.0)
+DEFAULT_TXT_COLOR = get_rgba_color((255, 255, 255, 1.0))
 # DEFAULT_TXT_THICKNESS = 1
 DEFAULT_SHADOW_COLOR = (0, 0, 0, 1.0)
 DEFAULT_OPACITY = 100
 
 
-DEFAULT_ROI_COLOR = (255, 150, 113, 0.4)
-DEFAULT_ROI_OUTLINE_COLOR = (70, 70, 70, 1.0)
+DEFAULT_ROI_COLOR = get_rgba_color((255, 150, 113, 0.4))
+DEFAULT_ROI_OUTLINE_COLOR = get_rgba_color((70, 70, 70, 1.0))
 DEFAULT_ROI_OUTLINE_THICKNESS = 1
-DEFAULT_LABEL_COLOR = (255, 255, 255, 0.4)
+DEFAULT_LABEL_COLOR = get_rgba_color((255, 255, 255, 0.4))
 DEFAULT_LABEL_SIZE = 50
 
 
